llm: rename -dump-ant-calls to -dump-llm

And tweak behavior.

Co-Authored-By: sketch <hello@sketch.dev>
Change-ID: s1605a29b744ae5f1k
diff --git a/dockerimg/dockerimg.go b/dockerimg/dockerimg.go
index d545a68..255e021 100644
--- a/dockerimg/dockerimg.go
+++ b/dockerimg/dockerimg.go
@@ -140,8 +140,8 @@
 	// PassthroughUpstream configures upstream remote for passthrough to innie
 	PassthroughUpstream bool
 
-	// DumpAntCalls enables dumping raw communications with Claude to files
-	DumpAntCalls bool
+	// DumpLLM requests dumping of raw communications with LLM services to files
+	DumpLLM bool
 }
 
 // LaunchContainer creates a docker container for a project, installs sketch and opens a connection to it.
@@ -648,8 +648,8 @@
 	if config.PassthroughUpstream {
 		cmdArgs = append(cmdArgs, "-passthrough-upstream")
 	}
-	if config.DumpAntCalls {
-		cmdArgs = append(cmdArgs, "-dump-ant-calls")
+	if config.DumpLLM {
+		cmdArgs = append(cmdArgs, "-dump-llm")
 	}
 
 	// Add additional docker arguments if provided